Learn R Programming

reproducible (version 0.1.3)

.prepareOutput: Make any modifications to object recovered from cacheRepo

Description

This is a generic definition that can be extended according to class.

Usage

.prepareOutput(object, cacheRepo, ...)

# S4 method for RasterLayer .prepareOutput(object, cacheRepo, ...)

# S4 method for ANY .prepareOutput(object, cacheRepo, ...)

Arguments

object

Any R object

cacheRepo

A repository used for storing cached objects. This is optional if Cache is used inside a SpaDES module.

...

Arguments of FUN function .

Value

The object, modified