Learn R Programming

reproducible (version 0.1.3)

.sortDotsUnderscoreFirst: Sort a any named object with dotted names first

Description

Internal use only. This exists so Windows and Linux machines can have the same order after a sort.

Usage

.sortDotsUnderscoreFirst(obj)

Arguments

obj

An arbitrary R object for which a names function returns a character vector.

Value

The same object as obj, but sorted with .objects first.

Examples

Run this code
# NOT RUN {
items <- c(A = "a", Z = "z", `.D` = ".d", `_W` = "_w")
.sortDotsUnderscoreFirst(items)

# }

Run the code above in your browser using DataLab