Learn R Programming

reproducible (version 3.2.1)

.whereInStack: Search for objects in the call stack

Description

Normally, this is only used in special, advanced uses. The standard approach to getting an object from an environment in the call stack is to explicitly pass it into the function.

Usage

.whereInStack(obj, startingEnv = parent.frame())

Value

The environment in which the object exists. It will return the first environment it finds, searching outwards from where the function is used.

Arguments

obj

Character string. The object name to search.

startingEnv

An environment to start searching in.