cacheId: Extract the cache id of an object

View source: R/helpers.R

cacheIdR Documentation

Extract the cache id of an object

Description

Any object that was returned from the Cache or was calculated as part of a Cache call will have an attribute, tags and an entry with ⁠cacheId:⁠ prefix. This is a lightweight helper to extract that cacheId.

Usage

cacheId(obj)

Arguments

obj

Any R object

Value

The cacheId if this was part of a Cache call. Otherwise NULL

Examples

# An object that was never Cached has no cacheId
cacheId(1:10)


reproducible documentation built on Aug. 26, 2026, 1:07 a.m.