| downloadFile | R Documentation |
Currently, this only deals with googledrive::drive_download,
and utils::download.file(). In general, this is not intended for use by a
user.
downloadFile(
archive,
targetFile,
neededFiles,
destinationPath = getOption("reproducible.destinationPath", "."),
quick,
checksumFile,
dlFun = NULL,
checkSums,
url,
needChecksums,
preDigest,
overwrite = getOption("reproducible.overwrite", TRUE),
alsoExtract = "similar",
verbose = getOption("reproducible.verbose", 1),
purge = FALSE,
.tempPath,
.callingEnv,
...
)
archive |
Optional character string giving the path of an archive
containing | ||||||||||||||||
targetFile |
Character string giving the filename (without relative or
absolute path) to the eventual file
(raster, shapefile, csv, etc.) after downloading and extracting from a zip
or tar archive. This is the file before it is passed to
| ||||||||||||||||
neededFiles |
Character string giving the name of the file(s) to be extracted. | ||||||||||||||||
destinationPath |
Character string of a directory in which to download
and save the file that comes from | ||||||||||||||||
quick |
Logical. This is passed internally to | ||||||||||||||||
checksumFile |
A character string indicating the absolute path to the | ||||||||||||||||
dlFun |
Optional "download function" name, such as | ||||||||||||||||
checkSums |
A checksums file, e.g., created by Checksums(..., write = TRUE) | ||||||||||||||||
url |
Optional character string indicating the URL to download from.
If not specified, then no download will be attempted. If not entry
exists in the | ||||||||||||||||
needChecksums |
A numeric, with | ||||||||||||||||
preDigest |
The list of | ||||||||||||||||
overwrite |
Logical. If | ||||||||||||||||
alsoExtract |
Which files to fetch or extract in addition to
The default depends on where the files are coming from, because "everything" only means something when a container bounds it:
An archive bounds what "all files" can mean, so Each element of a character vector may also be a regular expression: if an
element does not match any archive member literally (by relative path or
basename), it is passed to | ||||||||||||||||
verbose |
Numeric, -1 silent (where possible), 0 being very quiet,
1 showing more messaging, 2 being more messaging, etc.
Default is 1. Above 3 will output much more information about the internals of
Caching, which may help diagnose Caching challenges. Can set globally with an
option, e.g., | ||||||||||||||||
purge |
Logical or Integer. | ||||||||||||||||
.tempPath |
Optional temporary path for internal file intermediate steps.
Will be cleared | ||||||||||||||||
.callingEnv |
The environment where the function was called from. Used to find objects, if necessary. | ||||||||||||||||
... |
Passed to |
This function is called for its side effects, which will be a downloaded file
(targetFile), placed in destinationPath. This file will be checksummed, and
that checksum will be appended to the checksumFile.
Eliot McIntire
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.