| downloadRemote | R Documentation |
Download a remote file
downloadRemote(
url,
archive,
targetFile,
checkSums,
dlFun = NULL,
fileToDownload,
messSkipDownload,
destinationPath,
overwrite,
needChecksums,
.tempPath,
preDigest,
alsoExtract = "similar",
verbose = getOption("reproducible.verbose", 1),
.callingEnv = parent.frame(),
...
)
url |
Optional character string indicating the URL to download from.
If not specified, then no download will be attempted. If not entry
exists in the | ||||||||||||||||
archive |
Optional character string giving the path of an archive
containing | ||||||||||||||||
targetFile |
Character string giving the filename (without relative or
absolute path) to the eventual file
(raster, shapefile, csv, etc.) after downloading and extracting from a zip
or tar archive. This is the file before it is passed to
| ||||||||||||||||
checkSums |
TODO | ||||||||||||||||
dlFun |
Optional "download function" name, such as | ||||||||||||||||
fileToDownload |
TODO | ||||||||||||||||
messSkipDownload |
The character string text to pass to messaging if download skipped | ||||||||||||||||
destinationPath |
Character string of a directory in which to download
and save the file that comes from | ||||||||||||||||
overwrite |
Logical. Passed to | ||||||||||||||||
needChecksums |
Logical indicating whether to generate checksums. ## TODO: add overwrite arg to the function? | ||||||||||||||||
.tempPath |
Optional temporary path for internal file intermediate steps.
Will be cleared | ||||||||||||||||
preDigest |
The list of | ||||||||||||||||
alsoExtract |
Which files to fetch or extract in addition to
The default depends on where the files are coming from, because "everything" only means something when a container bounds it:
An archive bounds what "all files" can mean, so Each element of a character vector may also be a regular expression: if an
element does not match any archive member literally (by relative path or
basename), it is passed to | ||||||||||||||||
verbose |
Numeric, -1 silent (where possible), 0 being very quiet,
1 showing more messaging, 2 being more messaging, etc.
Default is 1. Above 3 will output much more information about the internals of
Caching, which may help diagnose Caching challenges. Can set globally with an
option, e.g., | ||||||||||||||||
.callingEnv |
The environment where the function was called from. Used to find objects, if necessary. | ||||||||||||||||
... |
Additional arguments passed to
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.