isLinux: Test whether system is Linux specifically

View source: R/helpers.R

isLinuxR Documentation

Test whether system is Linux specifically

Description

Distinct from isUnix(), which is TRUE on macOS too. Use isUnix() where something needs any unix-alike, and this where it must be Linux – e.g. the futurePlan and forking paths, which are enabled on Linux only.

Usage

isLinux()

reproducible documentation built on Aug. 26, 2026, 1:07 a.m.