isUnix: Test whether system is unix-alike (macOS, Linux, BSD, ...)

View source: R/helpers.R

isUnixR Documentation

Test whether system is unix-alike (macOS, Linux, BSD, ...)

Description

.Platform$OS.type is only ever "unix" or "windows", so this is the exact complement of isWindows(). Provided as a helper so tests can override it with testthat::local_mocked_bindings(), which is impossible when the check is written inline against .Platform.

Usage

isUnix()

reproducible documentation built on Aug. 26, 2026, 1:07 a.m.