loadFile: Load a file from the cache

View source: R/DBI.R

loadFileR Documentation

Load a file from the cache

Description

Load a file from the cache

Usage

loadFile(
  file,
  cacheId,
  cachePath,
  drv,
  conn,
  verbose = getOption("reproducible.verbose"),
  ...
)

Arguments

file

character(1) specifying the path to the file to load.

cacheId

character(1) the unique cache identifier of the object.

cachePath

character(1) path to the cache directory.

drv

A DBI driver object (e.g., RSQLite::SQLite()). Used when the cache format needs to be swapped.

conn

A DBI connection object. If NULL, a new connection is created internally as needed.

verbose

integer or logical. If ⁠> 0⁠ or TRUE, print informational messages. Defaults to getOption("reproducible.verbose").

...

Allows format for backward compatibility.

Value

the object loaded from file


reproducible documentation built on Aug. 26, 2026, 1:07 a.m.