| .purge | R Documentation |
Purge individual line items from checksums file
.purge(
checkSums,
purge,
targetFile,
archive,
alsoExtract,
url,
destinationPath
)
checkSums |
A checksums file, e.g., created by Checksums(..., write = TRUE) | ||||||||||||||||
purge |
Logical or Integer. | ||||||||||||||||
targetFile |
Character string giving the filename (without relative or
absolute path) to the eventual file
(raster, shapefile, csv, etc.) after downloading and extracting from a zip
or tar archive. This is the file before it is passed to
| ||||||||||||||||
archive |
Optional character string giving the path of an archive
containing | ||||||||||||||||
alsoExtract |
Which files to fetch or extract in addition to
The default depends on where the files are coming from, because "everything" only means something when a container bounds it:
An archive bounds what "all files" can mean, so Each element of a character vector may also be a regular expression: if an
element does not match any archive member literally (by relative path or
basename), it is passed to | ||||||||||||||||
url |
Optional character string indicating the URL to download from.
If not specified, then no download will be attempted. If not entry
exists in the | ||||||||||||||||
destinationPath |
Character string of a directory in which to download
and save the file that comes from |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.