rasterRead: A helper to 'getOption("reproducible.rasterRead")'

View source: R/helpers.R

rasterReadR Documentation

A helper to getOption("reproducible.rasterRead")

Description

A helper to getOption("reproducible.rasterRead")

Usage

rasterRead(...)

Arguments

...

Passed to the function parsed and evaluated from getOption("reproducible.rasterRead")

Value

A function, that will be the evaluated, parsed character string, e.g., eval(parse(text = "terra::rast"))

Examples


# returns the function named by getOption("reproducible.rasterRead")
rr <- getOption("reproducible.rasterRead")
rr


reproducible documentation built on Aug. 26, 2026, 1:07 a.m.