Learn R Programming

reproducible (version 3.2.1)

tempdir2: Make a temporary (sub-)directory

Description

Create a temporary subdirectory in getOption("reproducible.tempPath").

Usage

tempdir2(
  sub = "",
  tempdir = getOption("reproducible.tempPath", .reproducibleTempPath()),
  create = TRUE
)

Value

A character string of a path (that will be created if create = TRUE) in a sub-directory of the tempdir().

Arguments

sub

Character string, length 1. Can be a result of file.path("smth", "smth2") for nested temporary subdirectories. If the zero length character, then a random sub-directory will be created.

tempdir

Optional character string where the temporary directory should be placed. Defaults to getOption("reproducible.tempPath").

create

Logical. Should the directory be created. Default TRUE.

See Also

tempfile2

Examples

Run this code
td <- tempdir2("myProject")
dir.exists(td)
unlink(td, recursive = TRUE)

Run the code above in your browser using DataLab