tempfile2: Make a temporary file in a temporary (sub-)directory
Description
Make a temporary file in a temporary (sub-)directory
Usage
tempfile2(
sub = "",
tempdir = getOption("reproducible.tempPath", .reproducibleTempPath()),
...
)
Value
A character string of a path to a file in a
sub-directory of the tempdir(). This file will likely not exist yet.
Arguments
sub
Character string, length 1. Can be a result of
file.path("smth", "smth2") for nested temporary subdirectories.
If the zero length character, then a random sub-directory will be created.
tempdir
Optional character string where the temporary
directory should be placed. Defaults to getOption("reproducible.tempPath").