testForArchiveExtract: Returns 'unrar' path and creates a shortcut as...

testForArchiveExtractR Documentation

Returns unrar path and creates a shortcut as .systemArchivePath. Was not incorporated in previous function so it can be used in the tests.

Description

Returns unrar path and creates a shortcut as .systemArchivePath. Was not incorporated in previous function so it can be used in the tests.

Usage

.testForArchiveExtract(archive = "")

Value

path to unrar or 7-zip if it exists, and assign it to .systemArchivePath. Advise the user if not found..

Author(s)

Tati Micheletti


reproducible documentation built on Aug. 26, 2026, 1:07 a.m.