| writeFuture | R Documentation |
future::future (defunct)Defunct as of version 3.2.0. The future-based cache writing this supported was
never enabled by default – reproducible.futurePlan defaults to FALSE –
and has been removed. Cache() writes directly.
writeFuture(
written,
outputToSave,
cachePath,
userTags,
drv = getDrv(getOption("reproducible.drv", NULL)),
conn = getOption("reproducible.conn", NULL),
cacheId,
linkToCacheId = NULL,
verbose = getOption("reproducible.verbose")
)
written |
Integer. If zero or positive then it needs to be written still. Should be 0 to start. |
outputToSave |
The R object to save to repository |
cachePath |
The file path of the repository |
userTags |
Character string of tags to attach to this |
drv |
If using a database backend, |
conn |
an optional |
cacheId |
Character string. If passed, this will override the calculated hash
of the inputs, and return the result from this |
linkToCacheId |
Optional. If a |
verbose |
Numeric, -1 silent (where possible), 0 being very quiet,
1 showing more messaging, 2 being more messaging, etc.
Default is 1. Above 3 will output much more information about the internals of
Caching, which may help diagnose Caching challenges. Can set globally with an
option, e.g., |
Nothing; it signals a defunct error.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.