.listFilesInArchive: List files in either a .zip or or .tar file
Description
Makes the outputs from.tar``.zip the same, which they aren't by default.
Usage
.listFilesInArchive(archive, dontUse = NULL)
Value
A character string of all files in the archive.
Arguments
- archive
A character string of a single file name to list files in.
- dontUse
A character string or vector of unzipping tool(s) to not use,
e.g., one or more of: c("archive", "unzip", "7z")