This is a generic definition that can be extended according to class.
.prepareOutput(object, cacheRepo, ...)# S4 method for RasterLayer
.prepareOutput(object, cacheRepo, ...)
# S4 method for ANY
.prepareOutput(object, cacheRepo, ...)
Any R object
A repository used for storing cached objects.
This is optional if Cache is used inside a SpaDES module.
Arguments of FUN function .
The object, modified