powered by
Internal use only. This exists so Windows and Linux machines can have the same order after a sort.
.sortDotsUnderscoreFirst(obj)
An arbitrary R object for which a names function returns a character vector.
names
The same object as obj, but sorted with .objects first.
obj
# NOT RUN { items <- c(A = "a", Z = "z", `.D` = ".d", `_W` = "_w") .sortDotsUnderscoreFirst(items) # }
Run the code above in your browser using DataLab