| cacheId | R Documentation |
Any object that was returned from the Cache or was calculated as part of a
Cache call will have an attribute, tags and an entry with cacheId: prefix.
This is a lightweight helper to extract that cacheId.
cacheId(obj)
obj |
Any R object |
The cacheId if this was part of a Cache call. Otherwise NULL
# An object that was never Cached has no cacheId
cacheId(1:10)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.