Learn R Programming

reproducible (version 3.2.1)

cacheId: Extract the cache id of an object

Description

Any object that was returned from the Cache or was calculated as part of a Cache call will have an attribute, tags and an entry with cacheId: prefix. This is a lightweight helper to extract that cacheId.

Usage

cacheId(obj)

Value

The cacheId if this was part of a Cache call. Otherwise NULL

Arguments

obj

Any R object

Examples

Run this code
# An object that was never Cached has no cacheId
cacheId(1:10)

Run the code above in your browser using DataLab