Any object that was returned from the Cache or was calculated as part of a
Cache call will have an attribute, tags and an entry with cacheId: prefix.
This is a lightweight helper to extract that cacheId.
Usage
cacheId(obj)
Value
The cacheId if this was part of a Cache call. Otherwise NULL