Try to pick a file to load
.guessAtTargetAndFun(
targetFilePath,
destinationPath = getOption("reproducible.destinationPath", "."),
filesExtracted,
fun = NULL,
verbose = getOption("reproducible.verbose", 1),
messageGuessing = TRUE
)Full path of the directory where the target file should be
A character vector of all files that have been extracted (e.g., from an archive)
Logical. If TRUE (the default, used when a load will
follow, e.g. from prepInputs), emit the messages about the guessed
targetFile/fun (e.g. "targetFile was not specified", "Picking the last
one"). A direct preProcess() call sets this to FALSE because it never
loads the object, so those messages would be misleading; the guessing
itself (and the returned values) is unchanged.