| isLinux | R Documentation |
Distinct from isUnix(), which is TRUE on macOS too. Use isUnix() where
something needs any unix-alike, and this where it must be Linux – e.g. the
futurePlan and forking paths, which are enabled on Linux only.
isLinux()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.