Learn R Programming

reproducible (version 3.2.1)

isUnix: Test whether system is unix-alike (macOS, Linux, BSD, ...)

Description

.Platform$OS.type is only ever "unix" or "windows", so this is the exact complement of isWindows(). Provided as a helper so tests can override it with testthat::local_mocked_bindings(), which is impossible when the check is written inline against .Platform.

Usage

isUnix()

Arguments