Learn R Programming

reproducible (version 3.2.1)

rasterRead: A helper to getOption("reproducible.rasterRead")

Description

A helper to getOption("reproducible.rasterRead")

Usage

rasterRead(...)

Value

A function, that will be the evaluated, parsed character string, e.g., eval(parse(text = "terra::rast"))

Arguments

...

Passed to the function parsed and evaluated from getOption("reproducible.rasterRead")

Examples

Run this code
# returns the function named by getOption("reproducible.rasterRead")
rr <- getOption("reproducible.rasterRead")
rr

Run the code above in your browser using DataLab