| testForArchiveExtract | R Documentation |
unrar path and creates a shortcut as .systemArchivePath.
Was not incorporated in previous function so it can be used in the tests.Returns unrar path and creates a shortcut as .systemArchivePath.
Was not incorporated in previous function so it can be used in the tests.
.testForArchiveExtract(archive = "")
path to unrar or 7-zip if it exists, and assign it to .systemArchivePath.
Advise the user if not found..
Tati Micheletti
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.