testForArchiveExtract: Returns unrar path and creates a shortcut as .systemArchivePath.
Was not incorporated in previous function so it can be used in the tests.
Description
Returns unrar path and creates a shortcut as .systemArchivePath.
Was not incorporated in previous function so it can be used in the tests.
Usage
.testForArchiveExtract(archive = "")
Value
path to unrar or 7-zip if it exists, and assign it to .systemArchivePath.
Advise the user if not found..